@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import os
 
-from pagador.configuracao.cadastro import CampoFormulario, FormularioBase, TipoDeCampo, CadastroBase
+from pagador.configuracao.cadastro import CampoFormulario, FormularioBase, TipoDeCampo, CadastroBase, SelecaoBase
 from pagador.configuracao.cliente import Script, TipoScript
 
 eh_aplicacao = True
@@ -57,24 +57,10 @@ class MeioPagamentoEnvio(object):
         ]
 
 
-class MeioPagamentoSelecao(object):
-    logo = Script(tipo=TipoScript.html, nome="logo", conteudo=u'<img src="{{ STATIC_URL }}novo-template/img/bandeiras/mercadopago.png" title="Mercado Pago" alt="Mercado Pago">', eh_template=True)
-
-    @property
-    def bandeiras(self):
-        bandeiras = Script(tipo=TipoScript.html, nome="explicativo")
-        bandeiras.adiciona_linha('<ul class="bandeiras-pagamento">')
-        bandeiras.adiciona_linha('    <li><i class="icone-pagamento visa" title="Visa"></i></li>')
-        bandeiras.adiciona_linha('    <li><i class="icone-pagamento mastercard" title="Mastercard"></i></li>')
-        bandeiras.adiciona_linha('    <li><i class="icone-pagamento amex" title="Amex"></i></li>')
-        bandeiras.adiciona_linha('    <li><i class="icone-pagamento elo" title="Elo"></i></li>')
-        bandeiras.adiciona_linha('    <li><i class="icone-pagamento hipercard" title="Hipercard"></i></li>')
-        bandeiras.adiciona_linha('    <li><i class="icone-pagamento boleto" title="Hipercard"></i></li>')
-        bandeiras.adiciona_linha('    </ul>')
-        return bandeiras
+class MeioPagamentoSelecao(SelecaoBase):
+    selecao = Script(tipo=TipoScript.html, nome="selecao", caminho_arquivo=caminho_do_arquivo_de_template("selecao.html"), eh_template=True)
 
     def to_dict(self):
         return [
-            self.logo.to_dict(),
-            self.bandeiras.to_dict()
+            self.selecao.to_dict()
         ]
