@@ -10,16 +10,15 @@ from pagador_mercadopago.extensao.seguranca import ParametrosMercadoPago
 
 
 class EnviarPedido(Enviar):
-    def __init__(self, pedido, dados):
-        self.pedido = pedido
-        self.dados = self.gerar_dados_de_envio(dados)
+    def __init__(self, pedido, dados, configuracao_pagamento):
+        super(EnviarPedido, self).__init__(pedido, dados, configuracao_pagamento)
         self.exige_autenticacao = True
         self.processa_resposta = True
         self.url = "https://api.mercadolibre.com/checkout/preferences"
         self.grava_identificador = True
         self.envio_por_querystring = False
 
-    def gerar_dados_de_envio(self, dados):
+    def gerar_dados_de_envio(self):
         notification_url = MERCADOPAGO_PREFERENCE_NOTIFICATION_URL.format(self.pedido.conta.id)
         preferencia = Preferencia(
             auto_return="approved",
@@ -29,7 +28,7 @@ class EnviarPedido(Enviar):
                 name=self.pedido.cliente.nome.split()[0],
                 surname=self.pedido.cliente.nome.split()[-1],
                 email=self.pedido.cliente.email,
-                date_created=self.utils.formata_data(self.pedido.cliente.data_criacao, iso=True),
+                date_created=self.formatador.formata_data(self.pedido.cliente.data_criacao, iso=True),
                 phone=self.telefone,
                 identification=self.identificacao,
                 address=PayerAddress(
@@ -39,9 +38,9 @@ class EnviarPedido(Enviar):
                 )
             ),
             back_urls=BackUrls(
-                success="{}/success?next_url={}".format(notification_url, dados["next_url"]),
-                pending="{}/pending?next_url={}".format(notification_url, dados["next_url"]),
-                failure="{}/failure?next_url={}".format(notification_url, dados["next_url"])
+                success="{}/success?next_url={}".format(notification_url, self.dados["next_url"]),
+                pending="{}/pending?next_url={}".format(notification_url, self.dados["next_url"]),
+                failure="{}/failure?next_url={}".format(notification_url, self.dados["next_url"])
             ),
             shipments=Shipments(
                 receiver_address=ReceiverAddress(
@@ -79,7 +78,7 @@ class EnviarPedido(Enviar):
         elif self.pedido.cliente.telefone_celular:
             telefone = self.pedido.cliente.telefone_celular
         if telefone:
-            numero = self.utils.converte_tel_em_tupla_com_ddd(telefone)
+            numero = self.formatador.converte_tel_em_tupla_com_ddd(telefone)
             return Phone(area_code=numero[0], number=numero[1])
         return ''
 
@@ -90,14 +89,14 @@ class EnviarPedido(Enviar):
                 id=item.sku,
                 title=item.nome,
                 currency_id="BRL",
-                unit_price=self.utils.formata_decimal(item.preco_venda, como_float=True),
-                quantity=self.utils.formata_decimal(item.quantidade, como_float=True),
+                unit_price=self.formatador.formata_decimal(item.preco_venda, como_float=True),
+                quantity=self.formatador.formata_decimal(item.quantidade, como_float=True),
                 category_id="others",
                 picture_url=self.obter_url_da_imagem(item)
             )
             for item in self.pedido.itens.all()
         ]
-        items.append(Item(title="Frete", quantity=1, currency_id="BRL", unit_price=self.utils.formata_decimal(self.pedido.valor_envio, como_float=True)))
+        items.append(Item(title="Frete", quantity=1, currency_id="BRL", unit_price=self.formatador.formata_decimal(self.pedido.valor_envio, como_float=True)))
         return items
 
     def obter_situacao_do_pedido(self, status_requisicao):
