@@ -20,11 +20,12 @@ class SituacoesDePagamento(object):
 
 
 class Registro(RegistroBase):
-    def __init__(self, dados, tipo="retorno"):
-        super(Registro, self).__init__(dados)
+    def __init__(self, dados, tipo="retorno", configuracao=None):
+        super(Registro, self).__init__(dados, configuracao)
         self.exige_autenticacao = True
         self.processa_resposta = True
         self.tipo = tipo
+        self.envio_por_querystring = False
 
     @property
     def url(self):
